@@ -1,31 +1,31 @@
 <?php
 
 /*
-    Copyright (C) 2014-2015 Deciso B.V.
-    Copyright (C) 2012 Darren Embry <dse@webonastick.com>
-    All rights reserved.
-
-    Redistribution and use in source and binary forms, with or without
-    modification, are permitted provided that the following conditions are met:
-
-    1. Redistributions of source code must retain the above copyright notice,
-       this list of conditions and the following disclaimer.
-
-    2. Redistributions in binary form must reproduce the above copyright
-       notice, this list of conditions and the following disclaimer in the
-       documentation and/or other materials provided with the distribution.
-
-    THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
-    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
-    AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
-    AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
-    OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
-    SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
-    INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
-    CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
-    ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
-    POSSIBILITY OF SUCH DAMAGE.
-*/
+ * Copyright (C) 2014-2015 Deciso B.V.
+ * Copyright (C) 2012 Darren Embry <dse@webonastick.com>
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions and the following disclaimer.
+ *
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
+ * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+ * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+ * AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
+ * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
+ */
 
 require_once("guiconfig.inc");
 require_once("interfaces.inc");
@@ -45,6 +45,7 @@ $checkbox_names = array(
     'synchronizestaticroutes',
     'synchronizeusers',
     'synchronizevirtualip',
+    'synchronizewidgets',
 );
 
 $syncplugins = plugins_xmlrpc_sync();
@@ -150,7 +151,7 @@ include("head.inc");
                   <td>
                     <input type="checkbox" name="disablepreempt" value="on" <?= !empty($pconfig['disablepreempt']) ? "checked=\"checked\"" : "";?> />
                     <div class="hidden" data-for="help_for_disablepreempt">
-                      <?=gettext("When this device is configured as CARP master it will try to switch to master when powering up, this option will keep this one slave if there already is a master on the network");?>
+                      <?=gettext("When this device is configured as CARP master it will try to switch to master when powering up, this option will keep this one slave if there already is a master on the network. A reboot is required to take effect.");?>
                     </div>
                   </td>
                 </tr>
@@ -172,11 +173,11 @@ include("head.inc");
                     <div class="hidden" data-for="help_for_pfsyncinterface">
                       <?=gettext('If Synchronize States is enabled, it will utilize this interface for communication.') ?><br/><br/>
                       <div class="well">
-                        <lu>
+                        <ul>
                         <li><?=gettext('We recommend setting this to a interface other than LAN! A dedicated interface works the best.') ?></li>
                         <li><?=gettext('You must define an IP on each machine participating in this failover group.') ?></li>
                         <li><?=gettext('You must have an IP assigned to the interface on any participating sync nodes.') ?></li>
-                        </lu>
+                        </ul>
                       </div>
                     </div>
                   </td>
@@ -197,7 +198,10 @@ include("head.inc");
             <div class="table-responsive">
               <table class="table table-striped opnsense_standard_table_form">
                 <tr>
-                  <td colspan="2"><strong><?= gettext('Configuration Synchronization Settings (XMLRPC Sync)') ?></strong></td>
+                  <td colspan="2">
+                    <strong><?= gettext('Configuration Synchronization Settings (XMLRPC Sync)') ?></strong>
+                    <small><a href="/status_habackup.php"><?=gettext("Perform synchronization");?> </a></small>
+                  </td>
                 </tr>
                 <tr>
                   <td style="width:22%"><a id="help_for_synchronizetoip" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?= gettext('Synchronize Config to IP') ?></td>
@@ -238,12 +242,21 @@ include("head.inc");
                     </div>
                   </td>
                 </tr>
+                <tr>
+                  <td><a id="help_for_synchronizewidgets" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext('Dashboard') ?></td>
+                  <td>
+                    <input type="checkbox" name="synchronizewidgets" value="on" <?=!empty($pconfig['synchronizewidgets']) ? "checked=\"checked\"" : "";?> />
+                    <div class="hidden" data-for="help_for_synchronizewidgets">
+                      <?=gettext('Synchronize dashboard widgets.') ?>
+                    </div>
+                  </td>
+                </tr>
                 <tr>
                   <td><a id="help_for_synchronizeusers" href="#" class="showhelp"><i class="fa fa-info-circle"></i></a> <?=gettext('Users and Groups') ?></td>
                   <td>
                     <input type="checkbox" name="synchronizeusers" value="on" <?=!empty($pconfig['synchronizeusers']) ? "checked=\"checked\"" : "";?> />
                     <div class="hidden" data-for="help_for_synchronizeusers">
-                      <?=gettext('Automatically sync the users and groups over to the other HA host when changes are made.') ?>
+                      <?=gettext('Synchronize the users and groups over to the other HA host.') ?>
                     </div>
                   </td>
                 </tr>
@@ -252,7 +265,7 @@ include("head.inc");
                   <td>
                     <input type="checkbox" name='synchronizeauthservers' value="on" <?=!empty($pconfig['synchronizeauthservers']) ? "checked=\"checked\"" : "";?> />
                     <div class="hidden" data-for="help_for_synchronizeauthservers">
-                      <?=gettext('Automatically sync the authentication servers (e.g. LDAP, RADIUS) over to the other HA host when changes are made.') ?>
+                      <?=gettext('Synchronize the authentication servers (e.g. LDAP, RADIUS) over to the other HA host.') ?>
                     </div>
                   </td>
                 </tr>
@@ -261,7 +274,7 @@ include("head.inc");
                   <td>
                     <input type="checkbox" name="synchronizecerts" value="on" <?=!empty($pconfig['synchronizecerts']) ? "checked=\"checked\"" : "";?> />
                     <div class="hidden" data-for="help_for_synchronizecerts">
-                      <?=gettext('Automatically sync the Certificate Authorities, Certificates, and Certificate Revocation Lists over to the other HA host when changes are made.') ?>
+                      <?=gettext('Synchronize the Certificate Authorities, Certificates, and Certificate Revocation Lists over to the other HA host.') ?>
                     </div>
                   </td>
                 </tr>
@@ -270,7 +283,7 @@ include("head.inc");
                   <td>
                     <input type="checkbox" name="synchronizerules" value="on" <?=!empty($pconfig['synchronizerules']) ? "checked=\"checked\"" : "";?> />
                     <div class="hidden" data-for="help_for_synchronizerules">
-                      <?=gettext('Automatically sync the firewall rules to the other HA host when changes are made.') ?>
+                      <?=gettext('Synchronize the firewall rules to the other HA host.') ?>
                     </div>
                   </td>
                 </tr>
@@ -279,7 +292,7 @@ include("head.inc");
                   <td>
                     <input type="checkbox" name="synchronizeschedules" value="on" <?=!empty($pconfig['synchronizeschedules']) ? "checked=\"checked\"" :"";?> />
                     <div class="hidden" data-for="help_for_synchronizeschedules">
-                      <?=gettext('Automatically sync the firewall schedules to the other HA host when changes are made.') ?>
+                      <?=gettext('Synchronize the firewall schedules to the other HA host.') ?>
                     </div>
                   </td>
                 </tr>
@@ -288,7 +301,7 @@ include("head.inc");
                   <td>
                     <input type="checkbox" name="synchronizealiases" value="on" <?=!empty($pconfig['synchronizealiases']) ? "checked=\"checked\"" : "";?>/>
                     <div class="hidden" data-for="help_for_synchronizealiases">
-                      <?=gettext('Automatically sync the aliases over to the other HA host when changes are made.') ?>
+                      <?=gettext('Synchronize the aliases over to the other HA host.') ?>
                     </div>
                   </td>
                 </tr>
@@ -297,7 +310,7 @@ include("head.inc");
                   <td>
                     <input type="checkbox" name="synchronizenat" value="on" <?=!empty($pconfig['synchronizenat']) ? "checked=\"checked\"" :"";?> />
                     <div class="hidden" data-for="help_for_synchronizenat">
-                      <?=gettext('Automatically sync the NAT rules over to the other HA host when changes are made.') ?>
+                      <?=gettext('Synchronize the NAT rules over to the other HA host.') ?>
                     </div>
                   </td>
                 </tr>
@@ -306,7 +319,7 @@ include("head.inc");
                   <td>
                     <input type="checkbox" name="synchronizedhcpd" value="on" <?=!empty($pconfig['synchronizedhcpd']) ? "checked=\"checked\"" : "";?> />
                     <div class="hidden" data-for="help_for_synchronizedhcpd">
-                      <?=gettext('Automatically sync the DHCP Server settings over to the other HA host when changes are made. This only applies to DHCP for IPv4.') ?>
+                      <?=gettext('Synchronize the DHCP Server settings over to the other HA host. This only applies to DHCP for IPv4.') ?>
                     </div>
                   </td>
                 </tr>
@@ -315,7 +328,7 @@ include("head.inc");
                   <td>
                     <input type="checkbox" name="synchronizestaticroutes" value="on" <?=!empty($pconfig['synchronizestaticroutes']) ? "checked=\"checked\"" :"";?> />
                     <div class="hidden" data-for="help_for_synchronizestaticroutes">
-                      <?=gettext('Automatically sync the Static Route configuration to the other HA host when changes are made.') ?>
+                      <?=gettext('Synchronize the Static Route configuration to the other HA host.') ?>
                     </div>
                   </td>
                 </tr>
@@ -324,7 +337,7 @@ include("head.inc");
                   <td>
                     <input type="checkbox" name="synchronizevirtualip" value="on" <?=!empty($pconfig['synchronizevirtualip']) ? "checked=\"checked\"" : "";?> />
                     <div class="hidden" data-for="help_for_synchronizevirtualip">
-                      <?=gettext('Automatically sync the CARP Virtual IPs to the other HA host when changes are made.') ?>
+                      <?=gettext('Synchronize the CARP Virtual IPs to the other HA host.') ?>
                     </div>
                   </td>
                 </tr>
@@ -351,8 +364,8 @@ include("head.inc");
                 <tr>
                   <td style="width:22%"></td>
                   <td>
-                    <input name="Submit" type="submit" class="btn btn-primary" value="Save" />
-                    <input type="button" class="btn btn-default" value="<?=gettext("Cancel");?>" onclick="window.location.href='/system_hasync.php'" />
+                    <input name="Submit" type="submit" class="btn btn-primary" value="<?= html_safe(gettext('Save')) ?>" />
+                    <input type="button" class="btn btn-default" value="<?= html_safe(gettext('Cancel')) ?>" onclick="window.location.href='/system_hasync.php'" />
                   </td>
                 </tr>
               </table>
